@@ -60,20 +60,14 @@ import jsii
 import jsii.compat
 import publication
 
-import aws_cdk.aws_certificatemanager
-import aws_cdk.aws_cloudfront
-import aws_cdk.aws_route53_patterns
-import aws_cdk.aws_route53_targets
-import aws_cdk.aws_s3
-import aws_cdk.aws_s3_deployment
-import aws_cdk.core
+from ._jsii import *
 
-__jsii_assembly__ = jsii.JSIIAssembly.load("cdk-spa-deploy", "1.45.1", __name__, "cdk-spa-deploy@1.45.1.jsii.tgz")
+import aws_cdk.core
 
 
 @jsii.data_type(jsii_type="cdk-spa-deploy.HostedZoneConfig", jsii_struct_bases=[], name_mapping={'index_doc': 'indexDoc', 'website_folder': 'websiteFolder', 'zone_name': 'zoneName', 'error_doc': 'errorDoc'})
 class HostedZoneConfig():
-    def __init__(self, *, index_doc: str, website_folder: str, zone_name: str, error_doc: typing.Optional[str]=None):
+    def __init__(self, *, index_doc: str, website_folder: str, zone_name: str, error_doc: typing.Optional[str]=None) -> None:
         """
         :param index_doc: -
         :param website_folder: -
@@ -177,13 +171,13 @@ class SPADeploy(aws_cdk.core.Construct, metaclass=jsii.JSIIMeta, jsii_type="cdk-
         return jsii.get(self, "globalConfig")
 
     @global_config.setter
-    def global_config(self, value: "SPAGlobalConfig"):
+    def global_config(self, value: "SPAGlobalConfig") -> None:
         jsii.set(self, "globalConfig", value)
 
 
 @jsii.data_type(jsii_type="cdk-spa-deploy.SPADeployConfig", jsii_struct_bases=[], name_mapping={'index_doc': 'indexDoc', 'website_folder': 'websiteFolder', 'certificate_arn': 'certificateARN', 'cf_aliases': 'cfAliases', 'error_doc': 'errorDoc', 'export_website_url_name': 'exportWebsiteUrlName', 'export_website_url_output': 'exportWebsiteUrlOutput'})
 class SPADeployConfig():
-    def __init__(self, *, index_doc: str, website_folder: str, certificate_arn: typing.Optional[str]=None, cf_aliases: typing.Optional[typing.List[str]]=None, error_doc: typing.Optional[str]=None, export_website_url_name: typing.Optional[str]=None, export_website_url_output: typing.Optional[bool]=None):
+    def __init__(self, *, index_doc: str, website_folder: str, certificate_arn: typing.Optional[str]=None, cf_aliases: typing.Optional[typing.List[str]]=None, error_doc: typing.Optional[str]=None, export_website_url_name: typing.Optional[str]=None, export_website_url_output: typing.Optional[bool]=None) -> None:
         """
         :param index_doc: -
         :param website_folder: -
@@ -243,7 +237,7 @@ class SPADeployConfig():
 
 @jsii.data_type(jsii_type="cdk-spa-deploy.SPAGlobalConfig", jsii_struct_bases=[], name_mapping={'encrypt_bucket': 'encryptBucket', 'ip_filter': 'ipFilter', 'ip_list': 'ipList'})
 class SPAGlobalConfig():
-    def __init__(self, *, encrypt_bucket: typing.Optional[bool]=None, ip_filter: typing.Optional[bool]=None, ip_list: typing.Optional[typing.List[str]]=None):
+    def __init__(self, *, encrypt_bucket: typing.Optional[bool]=None, ip_filter: typing.Optional[bool]=None, ip_list: typing.Optional[typing.List[str]]=None) -> None:
         """
         :param encrypt_bucket: -
         :param ip_filter: -
@@ -277,6 +271,11 @@ class SPAGlobalConfig():
         return 'SPAGlobalConfig(%s)' % ', '.join(k + '=' + repr(v) for k, v in self._values.items())
 
 
-__all__ = ["HostedZoneConfig", "SPADeploy", "SPADeployConfig", "SPAGlobalConfig", "__jsii_assembly__"]
+__all__ = [
+    "HostedZoneConfig",
+    "SPADeploy",
+    "SPADeployConfig",
+    "SPAGlobalConfig",
+]
 
 publication.publish()
